@@ -19,7 +19,8 @@ define([
             , INDENT_DEPTH_PX
             , MAX_ITERATION
             , NUM_ZERO
-            
+            , NUM_DEFAULT_POS_X
+            , NUM_DEFAULT_POS_Y
             , STR_TOP
             , STR_LEFT
             , STR_DIV
@@ -57,6 +58,7 @@ define([
             , STR_PASS
             , STR_CODE
             , STR_ELIF
+            , STR_PROPERTY
 
             , STR_CSS_CLASS_VP_BLOCK_CONTAINER
             , STR_CSS_CLASS_VP_BLOCK_NULLBLOCK
@@ -99,7 +101,6 @@ define([
     var CreateBlockBtn = function(blockContainerThis, type) { 
         this.blockContainerThis = blockContainerThis;
         this.state = {
-            // identityNum: 100
             type
             , name: ''
             , isStart: false
@@ -197,6 +198,10 @@ define([
                 name = STR_PASS;
                 break;
             }
+            case BLOCK_CODE_TYPE.PROPERTY: {
+                name = STR_PROPERTY;
+                break;
+            }
             case BLOCK_CODE_TYPE.CODE: {
                 name = STR_CODE;
                 break;
@@ -262,20 +267,29 @@ define([
     CreateBlockBtn.prototype.render = function() {
         var blockContainer;
         var rootDomElement = $(`<div class='vp-nodeeditor-tab-navigation-node-block-body-btn'>
-                                    <span class='vp-block-name'>${this.getName()}</span>
+                                    <span class='vp-block-name'>
+                                        ${this.getName()}
+                                    </span>
                                 </div>`);
         this.setMainDom(rootDomElement);
-        if (this.getType() === BLOCK_CODE_TYPE.CLASS || this.getType() === BLOCK_CODE_TYPE.DEF) {
+
+        var blockCodeType = this.getType();
+        if (blockCodeType === BLOCK_CODE_TYPE.CLASS || blockCodeType === BLOCK_CODE_TYPE.DEF
+            || blockCodeType === BLOCK_CODE_TYPE.RETURN || blockCodeType === BLOCK_CODE_TYPE.PROPERTY) {
             blockContainer = $(`.vp-nodeeditor-tab-navigation-node-subblock-1-body-inner`);
             $(rootDomElement).addClass('vp-block-class-def');
-        } else if (this.getType() === BLOCK_CODE_TYPE.IF || this.getType() === BLOCK_CODE_TYPE.FOR
-            || this.getType() === BLOCK_CODE_TYPE.WHILE || this.getType() === BLOCK_CODE_TYPE.TRY
-            || this.getType() === BLOCK_CODE_TYPE.ELSE || this.getType() === BLOCK_CODE_TYPE.ELIF
-            || this.getType() === BLOCK_CODE_TYPE.FOR_ELSE || this.getType() === BLOCK_CODE_TYPE.EXCEPT 
-            || this.getType() === BLOCK_CODE_TYPE.FINALLY) {
+
+        } else if (blockCodeType === BLOCK_CODE_TYPE.IF || blockCodeType === BLOCK_CODE_TYPE.FOR
+            || blockCodeType === BLOCK_CODE_TYPE.WHILE || blockCodeType === BLOCK_CODE_TYPE.TRY
+            || blockCodeType === BLOCK_CODE_TYPE.ELSE || blockCodeType === BLOCK_CODE_TYPE.ELIF
+            || blockCodeType === BLOCK_CODE_TYPE.FOR_ELSE || blockCodeType === BLOCK_CODE_TYPE.EXCEPT 
+            || blockCodeType === BLOCK_CODE_TYPE.FINALLY) {
             blockContainer = $(`.vp-nodeeditor-tab-navigation-node-subblock-2-body-inner`);
             $(rootDomElement).addClass('vp-block-if');
   
+        } else if (blockCodeType === BLOCK_CODE_TYPE.BREAK || blockCodeType === BLOCK_CODE_TYPE.CONTINUE || blockCodeType === BLOCK_CODE_TYPE.PASS) {
+            blockContainer = $(`.vp-nodeeditor-tab-navigation-node-subblock-2-body-inner`);
+            $(rootDomElement).css(STR_BACKGROUND_COLOR, COLOR_RED);
         } else {
             blockContainer = $(`.vp-nodeeditor-tab-navigation-node-subblock-3-body-inner`);
             $(rootDomElement).css(STR_BACKGROUND_COLOR, COLOR_GREEN);
@@ -299,14 +313,17 @@ define([
         var pos4 = 0;
         var buttonX = 0;
         var buttonY = 0;
-        var newPointX = 0;
-        var newPointY = 0;
+        // var newPointX = 0;
+        // var newPointY = 0;
         var selectedBlockDirection;
         var shadowBlockList = [];
+
+        // var isCollision = false;
+        // var collitionBlock = null;
+
         $(this).addClass(`vp-nodeeditor-draggable`);
         $(rootDom).draggable({ 
             appendTo: STR_CSS_CLASS_VP_NODEEDITOR_LEFT,
-        
             cursor: 'move', 
             helper: 'clone',
             start: function(event, ui) {
@@ -324,7 +341,9 @@ define([
                 });
                 blockContainerThis.renderBlockLeftHolderListHeight();
             },
-            drag: (event, ui) => {                   
+            drag: (event, ui) => {       
+                // console.log('shadowBlockList', shadowBlockList);
+
                 blockContainerThis.renderBlockLeftHolderListHeight();
                 buttonX = event.clientX; 
                 buttonY = event.clientY; 
@@ -333,71 +352,91 @@ define([
                 pos2 = pos4 - buttonY;
                 pos3 = buttonX;
                 pos4 = buttonY;
-
-                newPointX = buttonX - pos2 - $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).offset().left;
+                var { x: thisX, 
+                      y: thisY, 
+                      width: thisBlockWidth,
+                      height: thisBlockHeight } = that.getMainDomPosition();
+                newPointX = buttonX - pos2 - $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).offset().left  - thisBlockWidth / 2;
                 newPointY = buttonY - pos1 - $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).offset().top;
-
+           
                 var blockList = blockContainerThis.getBlockList();
                 blockList.forEach(block => {
-                    var mainDom = block.getMainDom();
-                    var { x, y, width: blockWidth, height: blockHeight} = block.getMainDomPosition();
+            
+                    var { x , y
+                          , width: blockWidth
+                          , height: blockHeight } = block.getMainDomPosition();
                     var rootBlock = block.getRootBlock();
                     var blockCodeType = block.getType();
-            
-                    if ( x < buttonX && buttonX < (x + blockWidth)
-                        && y - blockHeight/2 < buttonY && buttonY < (y + blockHeight + blockHeight) ) { 
+
+                    var blockLeftHolderHeight = block.getTempBlockLeftHolderHeight() === 0 
+                                                                                        ? blockHeight 
+                                                                                        : block.getTempBlockLeftHolderHeight();
+                    // console.log(`${block.getName()} : blockLeftHolderHeight`, blockLeftHolderHeight);
+
+                    if ( (x > buttonX 
+                        || buttonX > (x + blockWidth)
+                        || y  > buttonY 
+                        || buttonY > (y + blockHeight + blockHeight /2 + blockLeftHolderHeight) )
+                        && block.getIsCollision() === true ) {
+                        // console.log(`${block.getName()}충돌 벗어남`);        
+                        block.renderBlockHolderShadow_2(STR_NONE);
+                        block.setIsCollision(false);
+                    }
+
+                    if ( x < buttonX
+                        && buttonX < (x + blockWidth )
+                        && y  < buttonY
+                        && buttonY < (y + blockHeight + blockLeftHolderHeight) ) {     
+                        block.renderBlockHolderShadow_2(STR_BLOCK);
+                    }
+
+                    if ( x < buttonX
+                        && buttonX < (x + blockWidth )
+                        && y  < buttonY
+                        && buttonY < (y + blockHeight  + blockHeight) ) {     
+                        // console.log(`${block.getName()}충돌`);
+                        var blockList = blockContainerThis.getBlockList();
+                        blockList.forEach(block => {
+                            block.setIsCollision(false);
+                        });
+
+                        block.setIsCollision(true);
+                        // block.renderBlockHolderShadow_2(STR_BLOCK);
+
+           
 
                         if (blockCodeType === BLOCK_CODE_TYPE.NULL) {
                             return;
                         }
+
+                        shadowBlockList.forEach(shadowBlock => {
+                            $(shadowBlock.getMainDom()).removeClass(STR_CSS_CLASS_VP_SELECTED_SHADOWBLOCK);
+                            $(shadowBlock.getMainDom()).css(STR_DISPLAY, STR_NONE);
+                            shadowBlock.setSelectBlock(null);
+                        });
+
                         shadowBlockList.some(shadowBlock => {
                             if (shadowBlock.getRootBlockUUID() === rootBlock.getUUID()) {
                                 $(shadowBlock.getMainDom()).css(STR_DISPLAY,STR_BLOCK);
                                 $(shadowBlock.getMainDom()).addClass(STR_CSS_CLASS_VP_SELECTED_SHADOWBLOCK);
                                 shadowBlock.setSelectBlock(block);
-
-                                if (blockCodeType === BLOCK_CODE_TYPE.CLASS || blockCodeType === BLOCK_CODE_TYPE.DEF || blockCodeType === BLOCK_CODE_TYPE.IF ||
-                                    blockCodeType === BLOCK_CODE_TYPE.FOR || blockCodeType === BLOCK_CODE_TYPE.WHILE || blockCodeType === BLOCK_CODE_TYPE.TRY || 
-                                    blockCodeType === BLOCK_CODE_TYPE.FOR_ELSE || blockCodeType === BLOCK_CODE_TYPE.EXCEPT || blockCodeType === BLOCK_CODE_TYPE.FINALLY) {
-         
-                                    block.getNextBlockList().some(nextBlock => {
-                                        if ( nextBlock.getType() === BLOCK_CODE_TYPE.NULL ) {
-                                            var holderBlock = block.getHolderBlock();
-                                            var blockLeftHolderHeight = block.getTempBlockLeftHolderHeight();
-                                            block.getBlockLeftHolderDom().css(STR_HEIGHT, `${blockLeftHolderHeight}px`);
-                                            //FIXME:
-                                            // $(holderBlock.getMainDom()).css('transform', `translate(0px, -34px)`); 
-                            
-                                            return true;
-                                        }
-                                    });
-                                }
-
-                                //FIXME:
-                                // if (blockCodeType === BLOCK_CODE_TYPE.HOLDER) {
-                                    // $(block.getMainDom()).css('transform', `translate(0px, 0px)`); 
-                                // }
-                                
                                 return true;
                             }
                         });
+
                         if (blockCodeType === BLOCK_CODE_TYPE.CLASS || blockCodeType === BLOCK_CODE_TYPE.DEF || blockCodeType === BLOCK_CODE_TYPE.IF ||
                             blockCodeType === BLOCK_CODE_TYPE.FOR || blockCodeType === BLOCK_CODE_TYPE.WHILE || blockCodeType === BLOCK_CODE_TYPE.TRY
+                            || blockCodeType === BLOCK_CODE_TYPE.ELIF || blockCodeType === BLOCK_CODE_TYPE.ELSE
                             || blockCodeType === BLOCK_CODE_TYPE.FOR_ELSE || blockCodeType === BLOCK_CODE_TYPE.EXCEPT || blockCodeType === BLOCK_CODE_TYPE.FINALLY) {
                             selectedBlockDirection = BLOCK_DIRECTION.INDENT;
-                        } else if (block.getType() === BLOCK_CODE_TYPE.HOLDER) {
+                        } else if (blockCodeType === BLOCK_CODE_TYPE.HOLDER) {
                             selectedBlockDirection = BLOCK_DIRECTION.DOWN; 
                         } else {
                             selectedBlockDirection = BLOCK_DIRECTION.DOWN; 
-                     
                         }
+
                         rootBlock.reArrangeChildBlockDomList(block, undefined, selectedBlockDirection);
                     } else {
-                        //FIXME:
-                        // if (blockCodeType === BLOCK_CODE_TYPE.HOLDER) {
-                            // $(block.getMainDom()).css('transform', `translate(0px, 0px)`); 
-                        // }
-           
                         var rootBlockList = blockContainerThis.getRootBlockList();
                         rootBlockList.some(rootBlock => {
                             var containerDom = rootBlock.getContainerDom();
@@ -411,10 +450,12 @@ define([
                                 // console.log('in colision');
                             } else {
                                 shadowBlockList.forEach(shadowBlock => {
-                                    if (shadowBlock.getRootBlockUUID() === rootBlock.getUUID()) {
+                                    // if (shadowBlock.getRootBlockUUID() === rootBlock.getUUID()) {
                                         $(shadowBlock.getMainDom()).removeClass(STR_CSS_CLASS_VP_SELECTED_SHADOWBLOCK);
+                                        $(shadowBlock.getMainDom()).css(STR_DISPLAY, STR_NONE);
                                         shadowBlock.setSelectBlock(null);
-                                    }    
+
+                                    // }    
                                 });
                                 // console.log('not colision');
                             }
@@ -424,38 +465,21 @@ define([
             },
             stop: function() {
                 var selectedBlock = null;
-     
                 var blockList = blockContainerThis.getBlockList();
-                // blockList.forEach(block => {
-                    // if (block.getType() === BLOCK_CODE_TYPE.HOLDER) {
-                        // $(block.getMainDom()).css('transform', `translate(0px, 0px)`); 
-                    // }
-                // });
 
                 var rootBlockList = blockContainerThis.getRootBlockList();
-
                 shadowBlockList.forEach(shadowBlock => {
                     if ( $(shadowBlock.getMainDom()).hasClass(STR_CSS_CLASS_VP_SELECTED_SHADOWBLOCK) ) {
                         selectedBlock = shadowBlock.getSelectBlock();
-                    } else {
-                    };
+                    } 
                 });
 
                 rootBlockList.forEach(rootBlock => {
                     var rootBlockContainerDom = rootBlock.getContainerDom();
                     $(rootBlockContainerDom).find(STR_CSS_CLASS_VP_BLOCK_SHADOWBLOCK).remove();
                 });
-
+                var blockList = blockContainerThis.getBlockList();
                 if (selectedBlock !== null) {
-                    if ((selectedBlock.getType() === BLOCK_CODE_TYPE.CLASS || selectedBlock.getType() === BLOCK_CODE_TYPE.DEF
-                        || selectedBlock.getType() === BLOCK_CODE_TYPE.IF || selectedBlock.getType() === BLOCK_CODE_TYPE.FOR
-                        || selectedBlock.getType() === BLOCK_CODE_TYPE.WHILE ||  selectedBlock.getType() === BLOCK_CODE_TYPE.TRY
-                        || selectedBlock.getType() === BLOCK_CODE_TYPE.FOR_ELSE || selectedBlock.getType() === BLOCK_CODE_TYPE.EXCEPT 
-                        || selectedBlock.getType() === BLOCK_CODE_TYPE.FINALLY)
-                        && selectedBlock.getNullBlock() !== null) {
-                        selectedBlock.getNullBlock().deleteBlockOne();
-                        selectedBlock.setNullBlock(null);
-                    } 
 
                     var block = mapTypeToBlock(blockContainerThis, createBlockBtnType, {pointX: 0, pointY: 0})
                     if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS || createBlockBtnType === BLOCK_CODE_TYPE.DEF ) {
@@ -469,78 +493,158 @@ define([
                     newPointX = x - $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).offset().left;
                     newPointY = y - $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).offset().top;
                     var containerDom = rootBlock.getContainerDom();
-
-                    $(containerDom).css(STR_TOP,`${y}${STR_PX}`);
-                    $(containerDom).css(STR_LEFT,`${x}${STR_PX}`);
-                    rootBlock.setContainerPointX(x);
-                    rootBlock.setContainerPointY(y);
+                   
+                    $(containerDom).css(STR_TOP,`${NUM_DEFAULT_POS_Y}${STR_PX}`);
+                    $(containerDom).css(STR_LEFT,`${NUM_DEFAULT_POS_X}${STR_PX}`);
+                    rootBlock.setContainerPointX(NUM_DEFAULT_POS_X);
+                    rootBlock.setContainerPointY(NUM_DEFAULT_POS_Y);
 
                     block.renderResetColor();
                     block.renderClickColor();
                     block.renderBottomOption();
-                    /** 생성된 BLOCK 색칠 
-                     *    block.renderWhiteColor();
-                    */
+                    block.selectThisBlock();
+                    block.calculateDepthFromRootBlockAndSetDepth();
                 }  else { 
-                    var block = mapTypeToBlock(blockContainerThis, createBlockBtnType, {pointX: 0, pointY: 0});
-                    /** 삭제 */
-                    {
-                        var containerDom = block.getContainerDom();
-                        $(containerDom).empty();
-                        $(containerDom).remove();
-                    }
-                    var containerDom = document.createElement(STR_DIV);
-                    containerDom.classList.add(STR_CSS_CLASS_VP_BLOCK_CONTAINER);
-                    block.setContainerDom(containerDom);
+                    if (blockList.length === 0) {
 
-                    var blockMainDom = block.getMainDom();
-                    $(containerDom).append(blockMainDom);
+                        var block = mapTypeToBlock(blockContainerThis, createBlockBtnType, {pointX: 0, pointY: 0});
+                        /** ContainerDom 삭제 */
+                        {
+                            var containerDom = block.getContainerDom();
+                            $(containerDom).empty();
+                            $(containerDom).remove();
+                        }
+                        var containerDom = document.createElement(STR_DIV);
+                        containerDom.classList.add(STR_CSS_CLASS_VP_BLOCK_CONTAINER);
+                        block.setContainerDom(containerDom);
 
-                    block.setContainerPointX(newPointX);
-                    block.setContainerPointY(newPointY);
+                        var blockMainDom = block.getMainDom();
+                        $(containerDom).append(blockMainDom);
 
-                    $(containerDom).css(STR_TOP,`${newPointY}${STR_PX}`);
-                    $(containerDom).css(STR_LEFT,`${newPointX}${STR_PX}`);
+                        block.setContainerPointX(NUM_DEFAULT_POS_X);
+                        block.setContainerPointY(NUM_DEFAULT_POS_Y);
+                        $(containerDom).css(STR_TOP,`${NUM_DEFAULT_POS_Y}${STR_PX}`);
+                        $(containerDom).css(STR_LEFT,`${NUM_DEFAULT_POS_X}${STR_PX}`);
 
-                    if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS || createBlockBtnType === BLOCK_CODE_TYPE.DEF 
-                        || createBlockBtnType === BLOCK_CODE_TYPE.IF ||
-                        createBlockBtnType === BLOCK_CODE_TYPE.FOR || createBlockBtnType === BLOCK_CODE_TYPE.WHILE 
-                        || createBlockBtnType === BLOCK_CODE_TYPE.TRY
-                        || createBlockBtnType === BLOCK_CODE_TYPE.FOR_ELSE || createBlockBtnType === BLOCK_CODE_TYPE.EXCEPT 
-                        || createBlockBtnType === BLOCK_CODE_TYPE.FINALLY) {
-               
-                        $(containerDom).append(block.getNullBlock().getMainDom());
-
-                        if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS || createBlockBtnType === BLOCK_CODE_TYPE.DEF ) {
-                            $(block.getHolderBlock().getMainDom()).css(STR_BACKGROUND_COLOR,`${COLOR_BLUE}`);
+                        if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS){
+                     
+                            $(containerDom).append(block.getNullBlock().getMainDom());
+                            $(containerDom).append(block.getNullBlock().getNullBlock().getMainDom());
+                            $(containerDom).append(block.getNullBlock().getHolderBlock().getMainDom());
+                            
+                            if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS || createBlockBtnType === BLOCK_CODE_TYPE.DEF ) {
+                                $(block.getHolderBlock().getMainDom()).css(STR_BACKGROUND_COLOR, COLOR_BLUE);
+                            }
+                            $(containerDom).append(block.getHolderBlock().getMainDom());
+                            block.bindHoverEvent();
                         }
 
-                        $(containerDom).append(block.getHolderBlock().getMainDom());
-            
-                        block.bindDragEvent();
-                        block.bindClickEvent();
+                        if (createBlockBtnType === BLOCK_CODE_TYPE.DEF 
+                            || createBlockBtnType === BLOCK_CODE_TYPE.IF || createBlockBtnType === BLOCK_CODE_TYPE.FOR 
+                            || createBlockBtnType === BLOCK_CODE_TYPE.WHILE || createBlockBtnType === BLOCK_CODE_TYPE.TRY
+                            || createBlockBtnType === BLOCK_CODE_TYPE.FOR_ELSE || createBlockBtnType === BLOCK_CODE_TYPE.EXCEPT 
+                            || createBlockBtnType === BLOCK_CODE_TYPE.FINALLY) {
+
+                            $(containerDom).append(block.getNullBlock().getMainDom());
+
+                            if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS || createBlockBtnType === BLOCK_CODE_TYPE.DEF ) {
+                                $(block.getHolderBlock().getMainDom()).css(STR_BACKGROUND_COLOR, COLOR_BLUE);
+                            }
+                            $(containerDom).append(block.getHolderBlock().getMainDom());
+                            block.bindHoverEvent();
+                        }
+
+                        $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).append(containerDom);
+                        block.renderResetColor();
+                        block.renderClickColor();
+                        block.renderBottomOption();
+                        block.selectThisBlock();
+                        block.calculateDepthFromRootBlockAndSetDepth();
+
+                        if (createBlockBtnType === BLOCK_CODE_TYPE.CLASS){
+                            block.calculateLeftHolderHeightAndSet();
+                            block.getNullBlock().calculateLeftHolderHeightAndSet();
+                        } else {
+                            block.calculateLeftHolderHeightAndSet();
+                        }
+                      
+                     
+                    } else {
+                        var rootBlockList = blockContainerThis.getRootBlockList();
+                        // rootBlockList.forEach(rootBlock => {
+
+                        // });
+                        var rootBlock = rootBlockList[0];
+
+                        var nextBlockList = rootBlock.getNextBlockList();
+                        var stack = [];
+                        if (nextBlockList.length !== 0) {
+                            stack.push(nextBlockList);
+                        }
+
+                        var current = null;
+                        while (stack.length !== 0) {
+                            current = stack.shift();
+                            if (Array.isArray(current)) {
+                                current.forEach(block => {
+                                    if (block.getDirection() === BLOCK_DIRECTION.DOWN) {
+                                        stack.unshift(block);
+                                    }
+                                });
+                            } else{
+                                var nextBlockList = current.getNextBlockList();
+                                var isDownBlock = nextBlockList.some(nextBlock => {
+                                    if (nextBlock.getDirection() === BLOCK_DIRECTION.DOWN) {
+                                        current = nextBlock;
+                                        stack.unshift(nextBlock);
+                                        return true;
+                                    }
+                                });
+                                if ( !isDownBlock ) {
+                                    break;
+                                }
+                            }
+                        }
+
+                        var blockCodeType = rootBlock.getType();
+                        var newBlock = mapTypeToBlock(blockContainerThis, createBlockBtnType, {pointX: 0, pointY: 0});
+
+                        if (blockCodeType === BLOCK_CODE_TYPE.CLASS || blockCodeType === BLOCK_CODE_TYPE.DEF || blockCodeType === BLOCK_CODE_TYPE.IF ||
+                            blockCodeType === BLOCK_CODE_TYPE.FOR || blockCodeType === BLOCK_CODE_TYPE.WHILE || blockCodeType === BLOCK_CODE_TYPE.TRY ||
+                            blockCodeType === BLOCK_CODE_TYPE.ELSE || blockCodeType === BLOCK_CODE_TYPE.ELIF || blockCodeType === BLOCK_CODE_TYPE.FOR_ELSE || 
+                            blockCodeType === BLOCK_CODE_TYPE.EXCEPT || blockCodeType === BLOCK_CODE_TYPE.FINALLY ) {
+                            if (current === null) {
+                                rootBlock.getHolderBlock().appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
+                            } else {
+                                current.appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
+                            }
+                        } else {
+                            if (current === null) {
+                                rootBlock.appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
+                            } else {
+                                current.appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
+                            }
+                        }
+
+                        newBlock.renderResetColor();
+                        newBlock.renderClickColor();
+                        newBlock.renderBottomOption();
+                        newBlock.selectThisBlock();
+                        newBlock.calculateDepthFromRootBlockAndSetDepth();
+                        newBlock.calculateLeftHolderHeightAndSet();
                     }
-                    $(STR_CSS_CLASS_VP_NODEEDITOR_LEFT).append(containerDom);
-                    block.renderResetColor();
-                    block.renderClickColor();
-                    block.renderBottomOption();
                 }
 
                 var blockList = blockContainerThis.getBlockList();
                 blockList.forEach(block => {
-                    if (block.getNullBlock()) {
-                        $(block.getNullBlock().getMainDom()).css(STR_DISPLAY, STR_BLOCK); 
-                    }
                     var mainDom = block.getMainDom();
+                    block.calculateWidthAndSet();
                     $(mainDom).find(STR_CSS_CLASS_VP_BLOCK_DELETE_BTN).remove();
+                    block.renderBlockHolderShadow(STR_NONE);
                 });
-                // var blockList = blockContainerThis.getBlockList();
-                // blockList.forEach((block, index) => {
-                //     if ( block.getNullBlock() ) {
-                //         $(block.getNullBlock().getMainDom()).css(STR_DISPLAY,STR_BLOCK); 
-                //     }
-                // });
+
                 blockContainerThis.renderBlockLeftHolderListHeight();
+                
                 /** 메모리에 남은 shadowBlockList 삭제 */
                 shadowBlockList = [];
             }
