@@ -39,6 +39,7 @@ define([
             , STR_STATIC
             , STR_RELATIVE
             , STR_ABSOLUTE
+            , STR_WIDTH
 
             , STR_CLASS
             , STR_DEF
@@ -130,11 +131,12 @@ define([
         rootDomElement.classList.add('vp-block');
         var type = this.getType();
 
-        if (type === BLOCK_CODE_TYPE.CLASS || type === BLOCK_CODE_TYPE.DEF) {
+        if (type === BLOCK_CODE_TYPE.CLASS || type === BLOCK_CODE_TYPE.DEF || type === BLOCK_CODE_TYPE.RETURN) {
             $(rootDomElement).css(STR_BACKGROUND_COLOR, `${COLOR_BLUE}`);
         } else if (type === BLOCK_CODE_TYPE.IF || type === BLOCK_CODE_TYPE.ELSE || type === BLOCK_CODE_TYPE.ELIF
             || type === BLOCK_CODE_TYPE.FOR || type === BLOCK_CODE_TYPE.WHILE || type === BLOCK_CODE_TYPE.TRY
-            || type === BLOCK_CODE_TYPE.FOR_ELSE || type === BLOCK_CODE_TYPE.EXCEPT || type === BLOCK_CODE_TYPE.FINALLY) {
+            || type === BLOCK_CODE_TYPE.FOR_ELSE || type === BLOCK_CODE_TYPE.EXCEPT || type === BLOCK_CODE_TYPE.FINALLY
+            || type === BLOCK_CODE_TYPE.BREAK || type === BLOCK_CODE_TYPE.CONTINUE || type === BLOCK_CODE_TYPE.PASS) {
             $(rootDomElement).css(STR_BACKGROUND_COLOR, `${COLOR_RED}`);
         }
 
@@ -157,6 +159,8 @@ define([
         $(rootDomElement).append(rootInnerDomElement);
 
         if (blockType === BLOCK_TYPE.BLOCK) {
+            var blockWidth = this.realBlock.getWidth();
+            $(rootDomElement).css(STR_WIDTH, blockWidth);
             if (type === BLOCK_CODE_TYPE.CLASS || type === BLOCK_CODE_TYPE.DEF) {
             
                 var blockLeftHolder = $('<div class="vp-block-left-holder"></div>');
