@@ -89,8 +89,11 @@ define([
         if (exec) {
             Jupyter.notebook.execute_cell();
 
-            // 추가 + 이진용 주임
-            vpCommon.renderSuccessMessage("코드가 실행되었습니다");
+            /**
+             * 추가 + 이진용 주임
+             * 2020 10 22 한글('코드가 실행되었습니다') -> 영어로 변경('your code has been executed)
+             */
+            vpCommon.renderSuccessMessage("your code has been executed");
         }
     }
 
@@ -169,8 +172,11 @@ define([
     VpFuncJS.prototype.metaSave = function() {
         if (this.package === undefined) return;
         var inputIdList = this.package.input.map(x => x.name);
-        inputIdList = inputIdList.concat(this.package.output.map(x => x.name));
-        inputIdList = inputIdList.concat(this.package.variable.map(x => x.name));
+        // inputIdList = inputIdList.concat(this.package.output.map(x => x.name));
+        // inputIdList = inputIdList.concat(this.package.variable.map(x => x.name));
+        // FIXME: minju : not existing object mapping error fixed
+        if (this.package.output) inputIdList = inputIdList.concat(this.package.output.map(x => x.name));
+        if (this.package.variable) inputIdList = inputIdList.concat(this.package.variable.map(x => x.name));
         // generate & save metadata
         this.initMetaHandler();
         
