@@ -12,7 +12,8 @@ define([
     const funcOptProp = {
         stepCount : 1
         , funcName : "To Period"
-        , funcID : "pd112"  // TODO: ID 규칙 생성 필요
+        , funcID : "pdPO_toPeriod"
+        , libID : "pd112"
     }
 
     /**
@@ -59,7 +60,7 @@ define([
     var PandasPackage = function(uuid) {
         this.uuid = uuid;   // Load html 영역의 uuid.
         // pandas 함수
-        this.package = libPandas._PANDAS_FUNCTION[funcOptProp.funcID];
+        this.package = libPandas._PANDAS_FUNCTION[funcOptProp.libID];
     }
 
 
